@@ -16,7 +16,7 @@ from django.core.exceptions import ImproperlyConfigured
 from django.db.models import get_app
 from django.http import HttpResponse, Http404
 from django.shortcuts import get_object_or_404, render_to_response
-from django.template import RequestContext
+from django.template import RequestContext, TemplateDoesNotExist, loader
 from django.utils import simplejson
 
 # internal imports
@@ -38,13 +38,14 @@ def add_or_modify(request, app_url, model_url, obj_id=None):
 
     cap_model = model_name.capitalize()
     form_name = '%sForm' % cap_model
-    template_name = '%s_%s.html' % (app_name, model_name)
+    template_name = get_template(app_name, model_name)
 
     models = get_models(app_name)
     cls = get_class(models, cap_model)
     form_obj = get_form(app_name, form_name, cls)
 
-    return process_request(request, cls, form_obj, obj_id, template_name)
+    return process_request(
+        request, cls, form_obj, form_name, obj_id, template_name)
 
 
 def get_models(app_name):
@@ -89,6 +90,10 @@ def get_form(app_name, form_name, cls):
 
 
 def get_template(app_name, model_name):
+    """
+    Gets template name.
+
+    """
     template_name = '%s_%s.html' % (app_name, model_name)
 
     if hasattr(settings, 'DTRANS_CONF'):
@@ -98,8 +103,12 @@ def get_template(app_name, model_name):
             template_name = '%s_%s_%s.html' % (
                 app_name, model_name, conf['template_sufix'])
 
-    return template_name
+    try:
+        loader.get_template(template_name)
+    except TemplateDoesNotExist:
+        template_name = 'dtrans_default_form.html'
 
+    return template_name
 
 
 def url_to_name(url, kind):
@@ -119,7 +128,7 @@ def url_to_name(url, kind):
     return name
 
 
-def process_request(request, cls, form_obj, obj_id, template):
+def process_request(request, cls, form_obj, form_name, obj_id, template):
     """
     Process Request
 
@@ -152,15 +161,12 @@ def process_request(request, cls, form_obj, obj_id, template):
         json = simplejson.dumps(res)
         return HttpResponse(json, mimetype='application/json')
 
+    data = {'form_name': form_name}
     if obj_id:
         obj = cls.objects.get(id=obj_id)
-        data = {
-            'obj_form': form_obj(instance=obj)
-        }
+        data['obj_form'] = form_obj(instance=obj)
     else:
-        data = {
-            'obj_form': form_obj()
-        }
+        data['obj_form'] = form_obj()
 
     return render_to_response(
         template, data, context_instance=RequestContext(request))
